@@ -9,7 +9,7 @@ class ConfigParser(ABC):
     @staticmethod
     @abstractmethod
     def get_managed_extensions() -> List[str]:
-        """Get file extensions managed by the parser.
+        """Get the file extensions managed by the parser.
 
         Returns:
             List of the managed extensions.
@@ -22,7 +22,7 @@ class ConfigParser(ABC):
         """Read config from a file using a specific protocol.
 
         Args:
-            cfg_file: the path to the file to be read.
+            cfg_file: The path to the file to be read.
 
         Returns:
             The config read from the given file.
@@ -35,7 +35,7 @@ class ConfigParser(ABC):
         """Write config into the given file using a specific protocol.
 
         Args:
-            cfg: the config to be saved.
-            cfg_file: the path to the output file.
+            cfg: The config to be saved.
+            cfg_file: The path to the output file.
         """
         ...
